require "MatchingGame"
require "GameLib"

local GameLib = GameLib
local MatchingGame = MatchingGame
local Apollo = Apollo
local next = next
local pairs = pairs

local addon = Apollo.GetPackage("Gemini:Addon-1.1").tPackage:NewAddon("SRSRatedBG", false, {}, "Gemini:Hook-1.0" )
local GeminiGUI = Apollo.GetPackage("Gemini:GUI-1.0").tPackage
local L = Apollo.GetPackage("Gemini:Locale-1.0").tPackage:GetLocale("SRSRatedBG", true)

local tConfirmPopUpDef = {
	AnchorOffsets = { -177, -179, 155, -57 },
	AnchorPoints = { 0.5, 0.5, 0.5, 0.5 },
	RelativeToClient = true,
	Name = "ConfirmPopUp",
	Picture = true,
	SwallowMouseClicks = true,
	Moveable = true,
	Escapable = true,
	Overlapped = true,
	Sprite = "CRB_Basekit:kitBase_HoloBlue_IconBaseStretch",
	Children = {
		{
			AnchorOffsets = { 10, 15, -10, 68 },
			AnchorPoints = { 0, 0, 1, 0 },
			RelativeToClient = true,
			Font = "CRB_Interface10_O",
			Text = L["Are you sure you want to queue for rated battlegrounds solo?"],
			Name = "ConfirmationText",
			TextColor = "xkcdAquaBlue",
			DT_CENTER = true,
			DT_VCENTER = true,
			DT_WORDBREAK = true,
		},
		{
			AnchorOffsets = { 70, -40, 130, -15 },
			AnchorPoints = { 0, 1, 0, 1 },
			Class = "Button",
			Base = "CRB_Basekit:kitBtn_List_Holo",
			Font = "Thick",
			ButtonType = "PushButton",
			DT_VCENTER = true,
			DT_CENTER = true,
			Name = "YesBtn",
			TextColor = "green",
			TextId = "Yes",
			UseWindowTextColor = true,
			Events = {
				ButtonSignal = "OnConfirmBtnClick",
			},
		},
		{
			AnchorOffsets = { 195, -40, 255, -15 },
			AnchorPoints = { 0, 1, 0, 1 },
			Class = "Button",
			Base = "CRB_Basekit:kitBtn_List_Holo",
			Font = "Thick",
			ButtonType = "PushButton",
			DT_VCENTER = true,
			DT_CENTER = true,
			Name = "NoBtn",
			TextColor = "red",
			TextId = "No",
			UseWindowTextColor = true,
			Events = {
				ButtonSignal = "OnConfirmBtnClick",
			},
		},
		{
			AnchorOffsets = { 5, 5, -5, -5 },
			AnchorPoints = { 0, 0, 1, 1 },
			RelativeToClient = true,
			BGColor = "UI_WindowBGDefault",
			TextColor = "UI_WindowTextDefault",
			Name = "Background",
			Picture = true,
			IgnoreMouse = true,
			Sprite = "CRB_Basekit:kitBase_HoloBlue_Tiny",
		},
	},
}

function addon:OnEnable()
	self:RawHook(Apollo.GetAddon("MatchMaker"),"OnJoin")
end

function addon:OnConfirmBtnClick(wHandler)
	if wHandler:GetName() == "YesBtn" then
		MatchingGame.Queue(wHandler:GetParent():GetData())
	end
	self.wPopUp:Destroy()
end

function addon:Confirm(matchesSelected)
	for strMatchName, oMatch in pairs(matchesSelected) do
		if oMatch:GetType() == 5 and not GameLib.GetPlayerUnit():IsInYourGroup() then -- rated BG and not grped
			self.wPopUp = GeminiGUI:Create(tConfirmPopUpDef):GetInstance(self)
			self.wPopUp:SetData(matchesSelected)
			return false
		end
	end
	return true
end

function addon:OnJoin(luaCaller) -- this is a RawHook aka we replace the function
	-- carbine code from the MatchMaker addon
	if next(luaCaller.matchesSelected) == nil then
		return
	end
	luaCaller.matchesQueued = {}

	for strMatchName, oMatch in pairs(luaCaller.matchesSelected) do
		luaCaller.matchesQueued[strMatchName] = oMatch
	end

	luaCaller.eQueuedTab = luaCaller.eSelectedTab

	if not self:Confirm(luaCaller.matchesSelected) then return end -- we call our confirmation window

	MatchingGame.Queue(luaCaller.matchesSelected)
end